@@ -60,7 +60,7 @@ func waitForService(client clientservingv1.KnServingClient, serviceName string,
 func showUrl(client clientservingv1.KnServingClient, serviceName string, originalRevision string, what string, out io.Writer) error {
 	service, err := client.GetService(serviceName)
 	if err != nil {
-		return fmt.Errorf("cannot fetch service '%s' in namespace '%s' for extracting the URL: %v", serviceName, client.Namespace(), err)
+		return fmt.Errorf("cannot fetch service '%s' in namespace '%s' for extracting the URL: %w", serviceName, client.Namespace(), err)
 	}
 
 	url := service.Status.URL.String()
