@@ -260,8 +260,9 @@ func printSourceList(sourceList *v1alpha2.ApiServerSourceList, options hprinters
 		return sourceList.Items[i].GetName() < sourceList.Items[j].GetName()
 	})
 
-	for _, item := range sourceList.Items {
-		row, err := printSource(&item, options)
+	for i := range sourceList.Items {
+		item := &sourceList.Items[i]
+		row, err := printSource(item, options)
 		if err != nil {
 			return nil, err
 		}
@@ -278,10 +279,11 @@ func printSourceListWithNamespace(sourceList *v1alpha2.ApiServerSourceList, opti
 	// temporary slice for sorting services in non-default namespace
 	others := []metav1beta1.TableRow{}
 
-	for _, source := range sourceList.Items {
+	for i := range sourceList.Items {
+		source := &sourceList.Items[i]
 		// Fill in with services in `default` namespace at first
 		if source.Namespace == "default" {
-			r, err := printSource(&source, options)
+			r, err := printSource(source, options)
 			if err != nil {
 				return nil, err
 			}
@@ -289,7 +291,7 @@ func printSourceListWithNamespace(sourceList *v1alpha2.ApiServerSourceList, opti
 			continue
 		}
 		// put other services in temporary slice
-		r, err := printSource(&source, options)
+		r, err := printSource(source, options)
 		if err != nil {
 			return nil, err
 		}
