@@ -40,14 +40,17 @@ import (
 
 // KnParams for creating commands. Useful for inserting mocks for testing.
 type KnParams struct {
-	Output             io.Writer
-	KubeCfgPath        string
-	ClientConfig       clientcmd.ClientConfig
-	NewServingClient   func(namespace string) (clientservingv1.KnServingClient, error)
-	NewSourcesClient   func(namespace string) (v1alpha2.KnSourcesClient, error)
-	NewEventingClient  func(namespace string) (clienteventingv1beta1.KnEventingClient, error)
-	NewMessagingClient func(namespace string) (clientmessagingv1beta1.KnMessagingClient, error)
-	NewDynamicClient   func(namespace string) (clientdynamic.KnDynamicClient, error)
+	Output                 io.Writer
+	KubeCfgPath            string
+	KubeContext            string
+	KubeCluster            string
+	ClientConfig           clientcmd.ClientConfig
+	NewServingClient       func(namespace string) (clientservingv1.KnServingClient, error)
+	NewGitopsServingClient func(namespace string, dir string) (clientservingv1.KnServingClient, error)
+	NewSourcesClient       func(namespace string) (v1alpha2.KnSourcesClient, error)
+	NewEventingClient      func(namespace string) (clienteventingv1beta1.KnEventingClient, error)
+	NewMessagingClient     func(namespace string) (clientmessagingv1beta1.KnMessagingClient, error)
+	NewDynamicClient       func(namespace string) (clientdynamic.KnDynamicClient, error)
 
 	// General global options
 	LogHTTP bool
@@ -61,6 +64,10 @@ func (params *KnParams) Initialize() {
 		params.NewServingClient = params.newServingClient
 	}
 
+	if params.NewGitopsServingClient == nil {
+		params.NewGitopsServingClient = params.newGitopsServingClient
+	}
+
 	if params.NewSourcesClient == nil {
 		params.NewSourcesClient = params.newSourcesClient
 	}
@@ -84,10 +91,17 @@ func (params *KnParams) newServingClient(namespace string) (clientservingv1.KnSe
 		return nil, err
 	}
 
-	client, _ := servingv1client.NewForConfig(restConfig)
+	client, err := servingv1client.NewForConfig(restConfig)
+	if err != nil {
+		return nil, err
+	}
 	return clientservingv1.NewKnServingClient(client, namespace), nil
 }
 
+func (params *KnParams) newGitopsServingClient(namespace string, dir string) (clientservingv1.KnServingClient, error) {
+	return clientservingv1.NewKnServingGitOpsClient(namespace, dir), nil
+}
+
 func (params *KnParams) newSourcesClient(namespace string) (v1alpha2.KnSourcesClient, error) {
 	restConfig, err := params.RestConfig()
 	if err != nil {
@@ -155,14 +169,21 @@ func (params *KnParams) RestConfig() (*rest.Config, error) {
 // GetClientConfig gets ClientConfig from KubeCfgPath
 func (params *KnParams) GetClientConfig() (clientcmd.ClientConfig, error) {
 	loadingRules := clientcmd.NewDefaultClientConfigLoadingRules()
+	configOverrides := &clientcmd.ConfigOverrides{}
+	if params.KubeContext != "" {
+		configOverrides.CurrentContext = params.KubeContext
+	}
+	if params.KubeCluster != "" {
+		configOverrides.Context.Cluster = params.KubeCluster
+	}
 	if len(params.KubeCfgPath) == 0 {
-		return clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, &clientcmd.ConfigOverrides{}), nil
+		return clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, configOverrides), nil
 	}
 
 	_, err := os.Stat(params.KubeCfgPath)
 	if err == nil {
 		loadingRules.ExplicitPath = params.KubeCfgPath
-		return clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, &clientcmd.ConfigOverrides{}), nil
+		return clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, configOverrides), nil
 	}
 
 	if !os.IsNotExist(err) {
@@ -171,8 +192,8 @@ func (params *KnParams) GetClientConfig() (clientcmd.ClientConfig, error) {
 
 	paths := filepath.SplitList(params.KubeCfgPath)
 	if len(paths) > 1 {
-		return nil, fmt.Errorf("Can not find config file. '%s' looks like a path. "+
+		return nil, fmt.Errorf("can not find config file. '%s' looks like a path. "+
 			"Please use the env var KUBECONFIG if you want to check for multiple configuration files", params.KubeCfgPath)
 	}
-	return nil, fmt.Errorf("Config file '%s' can not be found", params.KubeCfgPath)
+	return nil, fmt.Errorf("config file '%s' can not be found", params.KubeCfgPath)
 }
