@@ -17,10 +17,10 @@ package config
 import (
 	"testing"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 )
 
-// Dummy test to keep code coverage quality gate happy.
+// Test to keep code coverage quality gate happy.
 //
 func TestTestConfig(t *testing.T) {
 	cfg := TestConfig{
