@@ -25,7 +25,7 @@ import (
 	"testing"
 
 	"github.com/spf13/cobra"
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 )
 
 var testPluginScriptUnix = `#!/bin/bash
